@@ -2,6 +2,7 @@ import argparse
 import ConfigParser as configparser
 import functools
 import os
+import re
 import shutil
 import socket
 import subprocess
@@ -9,6 +10,7 @@ import sys
 import tempfile
 import textwrap
 from contextlib import contextmanager
+from decimal import Decimal
 from pprint import pprint
 
 import netifaces
@@ -57,6 +59,20 @@ def check_git_config(args, parser):
             print
 
 
+def revs(args, parser):
+    for branch in BRANCHES:
+        branch_dir = join(locations()['tree'], branch)
+        with pushd(branch_dir):
+            os.chdir(branch_dir)
+            active_branch = subprocess.check_output([
+                'git', 'rev-parse', '--abbrev-ref', 'HEAD'])
+            rev = subprocess.check_output([
+                'git', 'log', '-n', '1',
+                '--pretty=oneline', '--abbrev-commit'])
+            print "{0}: {1} [{2}]".format(branch, rev.split()[0],
+                                          active_branch.rstrip())
+
+
 def checkout(args, parser, gh_username=None):
     if not locations()['tree']:
         parser.error('Please set a location by calling root first.')
@@ -120,6 +136,12 @@ def locations():
 
 
 def root(args, parser):
+    if not args.directory:
+        value = get_config_value('paths', 'root')
+        if value:
+            print value
+        return
+
     directory = os.path.abspath(os.path.expandvars(args.directory))
     if not os.path.exists(directory):
         raise ValueError('Directory {0} does not exist.'.format(directory))
@@ -162,6 +184,36 @@ def bash(args, parser):
     return
 
 
+def get_version(method):
+    methods = {
+        'docker': [
+            'Client version: (\d.\d).*?Server version: (\d.\d)',
+            ['docker', 'version']
+        ],
+        'boot2docker': [
+            '^Boot2Docker-cli version: v(\d.\d)',
+            ['boot2docker', 'version']
+        ],
+        'fig': ['^fig (\d.\d)', ['fig', '--version']]
+    }
+    regex, command = methods[method]
+    try:
+        result = subprocess.check_output(command).strip()
+    except OSError:
+        raise ValueError('Command: "{0}" failed, is it installed?'
+                         .format(' '.join(command)))
+
+    try:
+        res = re.findall(regex, result, flags=re.S)
+        if isinstance(res[0], tuple):
+            res = res[0]
+    except IndexError:
+        raise ValueError('Command: "{0}" returned an unknown value.'
+                         .format(' '.join(command)))
+
+    return [Decimal(v) for v in res]
+
+
 def check(args, parser):
     context = locations()
     default = os.getenv('FIG_FILE')
@@ -210,6 +262,17 @@ def check(args, parser):
                 pprint(res.json())
                 print
 
+    if args.versions:
+        dockers = get_version('docker')
+        for version in dockers:
+            if version < Decimal('1.3'):
+                print ('Update docker, client or server version 1.3 or higher '
+                       'is recommended. Run: docker version')
+        if get_version('boot2docker')[0] < Decimal('1.3'):
+            print 'Update boot2docker, version 1.3 or higher recommended.'
+        if get_version('fig')[0] < Decimal('1.0'):
+            print 'Update fig, version 1.0 or higher recommended.'
+
 
 def update(args, parser):
     git, migration = args.git, args.migrations
@@ -484,7 +547,8 @@ def create_parser():
         'root', help='Create or update the root paths in the fig.yml.'
     )
     parser_root.add_argument(
-        'directory', help='Path to the marketplace repositories.'
+        'directory', help='Path to the marketplace repositories.',
+        default=None, nargs='?'
     )
     parser_root.set_defaults(func=root)
 
@@ -513,6 +577,10 @@ def create_parser():
         '--services', help='Checks the status page of each service.',
         action='store_true'
     )
+    parser_check.add_argument(
+        '--versions', help='Checks versions of docker, boot2docker and fig',
+        action='store_true'
+    )
     parser_check.set_defaults(func=check)
 
     parser_up = subparsers.add_parser(
@@ -526,6 +594,11 @@ def create_parser():
     )
     parser_checkgitconfig.set_defaults(func=check_git_config)
 
+    parser_revs = subparsers.add_parser(
+        'revs', help='Print out the git revs for the trees'
+    )
+    parser_revs.set_defaults(func=revs)
+
     parser_whoami = subparsers.add_parser(
         'whoami', help='Check or store your github credentials'
     )
